@@ -85,8 +85,9 @@
 #' with the decision. If that is the case decision and confidence judgment are assumed to have happened
 #' subsequent before the response. Therefore `tau` is included in the response time. If the decision was
 #' reported before the confidence report, `simul_conf` should be `FALSE`.
-#' @param precision numerical scalar value. Precision of calculation. Corresponds to the
-#' step size of integration w.r.t. `z` and `t0`. Default is 1e-5.
+#' @param precision numerical scalar value. Precision of calculation. Determines the
+#' step size of integration w.r.t. `z` and `t0`.
+#' Represents the number of decimals precisely computed on average. Default is 6.
 #' @param z_absolute logical. Determines whether `z` is treated as absolute start point
 #' (`TRUE`) or relative (`FALSE`; default) to `a`.
 #' @param stop_on_error Should the diffusion functions return 0 if the parameters values are
@@ -102,12 +103,12 @@
 #' state of the decision (and visibility) process as additional column. Default is FALSE, meaning that
 #' no additional columns for the final process states are returned.
 #'
-#' @return \code{dWEV} gives the density/likelihood/probability of the diffusion process producing
+#' @return \code{ddynaViTE} gives the density/likelihood/probability of the diffusion process producing
 #' a decision of \code{response} at time \code{rt} and a confidence judgment corresponding to the
 #' interval \[ \code{th1}, \code{th2}\]. The value will be a numeric vector of the same length as
 #' \code{rt}.
 #'
-#' \code{rWEV} returns a `data.frame` with three columns and `n` rows. Column names are `rt` (response
+#' \code{rdynaViTE} returns a `data.frame` with three columns and `n` rows. Column names are `rt` (response
 #' time), `response` (-1 (lower) or 1 (upper), indicating which bound was hit), and `conf` (the
 #' value of the confidence measure; not discretized!).
 #'
@@ -115,8 +116,13 @@
 #' \code{w} and \code{sig}) are recycled to the length of the result. In other words, the functions
 #' are completely vectorized for all parameters and even the response boundary.
 #'
-#' @details The dynamical visibility, time, and evidence (dynaViTE) model
-#' and the weighted evidence and visibility model are extensions of the 2DSD model
+#' @details
+#' The function dWEV was renamed to ddynaViTE in version 0.1.0 of the package.
+#' It is still here for reasons of backwards compatibility. The function just calls the
+#' ddynaViTE function (and produces a deprecation warning).
+#'
+#' The dynamical visibility, time, and evidence (dynaViTE) model
+#' and the weighted evidence and visibility model (dynWEV) are extensions of the 2DSD model
 #' for decision confidence (see \code{\link{d2DSD}}). It assumes that the decision follows a drift
 #' diffusion model with two additional assumptions to account for confidence. First, there is a
 #' post-decisional period of further evidence accumulation `tau`. Second, another accumulation process
@@ -157,30 +163,30 @@
 #' @useDynLib dynConfiR, .registration = TRUE
 #'
 #' @name dynaViTE
-#' @aliases WEVmodel dWEV ddynWEV rWEV dynWEV
+#' @aliases WEVmodel ddynaViTE ddynWEV rdynaViTE dynWEV dWEV
 #' @importFrom Rcpp evalCpp
 #'
 #' @examples
 #' # Plot rt distribution ignoring confidence
-#' curve(dWEV(x, "upper", -Inf, Inf, tau=1, a=2, v=0.4, sz=0.2, sv=0.9), xlim=c(0, 2), lty=2)
-#' curve(dWEV(x, "lower", -Inf, Inf,tau=1, a=2, v=0.4, sz=0.2, sv=0.9), col="red", lty=2, add=TRUE)
-#' curve(dWEV(x, "upper", -Inf, Inf,  tau=1, a=2, v=0.4),add=TRUE)
-#' curve(dWEV(x, "lower", -Inf, Inf, tau=1, a=2, v=0.4), col="red", add=TRUE)
+#' curve(ddynaViTE(x, "upper", -Inf, Inf, tau=1, a=2, v=0.4, sz=0.2, sv=0.9), xlim=c(0, 2), lty=2)
+#' curve(ddynaViTE(x, "lower", -Inf, Inf,tau=1, a=2, v=0.4, sz=0.2, sv=0.9))
+#' curve(ddynaViTE(x, "upper", -Inf, Inf,  tau=1, a=2, v=0.4),add=TRUE)
+#' curve(ddynaViTE(x, "lower", -Inf, Inf, tau=1, a=2, v=0.4), col="red", add=TRUE)
 #' # Generate a random sample
-#' df1 <- rWEV(5000, a=2,v=0.5,t0=0,z=0.5,d=0,sz=0,sv=0, st0=0,  tau=1, s=1, w=0.9)
+#' df1 <- rdynaViTE(5000, a=2,v=0.5,t0=0,z=0.5,d=0,sz=0,sv=0, st0=0,  tau=1, s=1, w=0.9)
 #' # Same RT and response distribution but different confidence distribution
-#' df2 <- rWEV(5000, a=2,v=0.5,t0=0,z=0.5,d=0,sz=0,sv=0, st0=0,  tau=1, s=1, w=0.1)
+#' df2 <- rdynaViTE(5000, a=2,v=0.5,t0=0,z=0.5,d=0,sz=0,sv=0, st0=0,  tau=1, s=1, w=0.1)
 #' head(df1)
 #'
 #' # Scaling diffusion parameters leads do same density values
-#' dWEV(df1[1:5,], th1=-Inf, th2=Inf, a=2, v=.5)[1:5]
+#' ddynaViTE(df1[1:5,], th1=-Inf, th2=Inf, a=2, v=.5)[1:5]
 #' s <- 2
-#' dWEV(df1[1:5,], th1=-Inf, th2=Inf, a=2*s, v=.5*s, s=2)[1:5]
+#' ddynaViTE(df1[1:5,], th1=-Inf, th2=Inf, a=2*s, v=.5*s, s=2)[1:5]
 #'
 #' # Diffusion constant also scales confidence parameters
-#' dWEV(df1[1:5,], th1=0.2, th2=1, a=2, v=.5, sv=0.2, w=0.5, sigvis = 0.2, svis = 1)[1:5]
+#' ddynaViTE(df1[1:5,], th1=0.2, th2=1, a=2, v=.5, sv=0.2, w=0.5, sigvis = 0.2, svis = 1)[1:5]
 #' s <- 2
-#' dWEV(df1[1:5,], th1=0.2*s, th2=1*s, a=2*s, v=.5*s, s=2,
+#' ddynaViTE(df1[1:5,], th1=0.2*s, th2=1*s, a=2*s, v=.5*s, s=2,
 #'      sv=0.2*s, w=0.5, sigvis=0.2*s, svis=1*s)[1:5]
 #'
 #'
@@ -200,18 +206,32 @@
 #'
 #' # Restricting to specific confidence region
 #' df1 <- df1[df1$conf >0 & df1$conf <1,]
-#' dWEV(df1[1:5,], th1=0, th2=1, a=2, v=0.5)[1:5]
+#' ddynaViTE(df1[1:5,], th1=0, th2=1, a=2, v=0.5)[1:5]
 #'
 #' # If lower confidence threshold is higher than the upper, the function throws an error,
 #' # except when stop_on_error is FALSE
-#' dWEV(df1[1:5,], th1=1, th2=0, a=2, v=0.5, stop_on_error = FALSE)
+#' ddynaViTE(df1[1:5,], th1=1, th2=0, a=2, v=0.5, stop_on_error = FALSE)
 #'
 
 #' @rdname dynaViTE
 #' @export
 dWEV <- function (rt, response="upper", th1,th2, a,v,t0=0,z=0.5,d=0,sz=0,sv=0, st0=0,
+                       tau=1, w=0.5, muvis=NULL, sigvis=0, svis=1,
+                       lambda = 0, s=1,  simult_conf = FALSE, precision=6, z_absolute = FALSE,
+                       stop_on_error=TRUE, stop_on_zero=FALSE) {
+  warning("The function dWEV was renamed to ddynaViTE in version 0.1.0 of the package.\\
+          It will be removed in future releases of the package!")
+  return(ddynaViTE(rt, response="upper", th1,th2, a,v,t0=0,z=0.5,d=0,sz=0,sv=0, st0=0,
+                         tau=1, w=0.5, muvis=NULL, sigvis=0, svis=1,
+                         lambda = 0, s=1,  simult_conf = FALSE, precision=6, z_absolute = FALSE,
+                         stop_on_error=TRUE, stop_on_zero=FALSE))
+}
+
+#' @rdname dynaViTE
+#' @export
+ddynaViTE <- function (rt, response="upper", th1,th2, a,v,t0=0,z=0.5,d=0,sz=0,sv=0, st0=0,
                   tau=1, w=0.5, muvis=NULL, sigvis=0, svis=1,
-                  lambda = 0, s=1,  simult_conf = FALSE, precision=1e-5, z_absolute = FALSE,
+                  lambda = 0, s=1,  simult_conf = FALSE, precision=6, z_absolute = FALSE,
                   stop_on_error=TRUE, stop_on_zero=FALSE)
 {
   # for convenience accept data.frame as first argument.
@@ -255,7 +275,7 @@ dWEV <- function (rt, response="upper", th1,th2, a,v,t0=0,z=0.5,d=0,sz=0,sv=0, s
 
 #' @rdname dynaViTE
 #' @export
-rWEV <- function (n, a,v,t0=0,z=0.5,d=0,sz=0,sv=0, st0=0,
+rdynaViTE <- function (n, a,v,t0=0,z=0.5,d=0,sz=0,sv=0, st0=0,
                   tau=1, w=0.5, muvis=NULL, sigvis=0, svis=1,
                   lambda=0, s=1, delta=0.01, maxrt=15, simult_conf = FALSE,
                   z_absolute = FALSE,  stop_on_error=TRUE, process_results=FALSE)
